package cmd

import (
	"encoding/base64"
	"io/ioutil"

	"orus.io/orus-io/rednerd/models"
)

type Template struct {
	Account string
	Name    string

	Language string `long:"language"`
	Produces string `long:"produces"`
	Version  string

	Data     string
	DataFile string
}

func (t Template) ToModelTemplate() (*models.Template, error) {
	var body []byte
	if t.Data != "" {
		body = []byte(t.Data)
	} else if t.DataFile != "" {
		b, err := ioutil.ReadFile(t.DataFile)
		if err != nil {
			return nil, err
		}
		body = b
	}
	return &models.Template{
		Account:    t.Account,
		Name:       t.Name,
		Language:   t.Language,
		Produces:   t.Produces,
		Version:    t.Version,
		Body:       base64.StdEncoding.EncodeToString(body),
		BodyFormat: "base64",
	}, nil
}
